@@ -110,6 +110,12 @@ class Session(object):
             except:
                 print "Error on save configuration"
 
+    def start_mail_client(self):
+        pass
+
+    def stop_mail_client(self):
+        pass
+
     def load_config(self):
         '''load the config of the session'''
         # load the global configuration
