@@ -42,9 +42,8 @@ class Worker(e3.Worker):
                 '', True)
         self._add_contact('pochu@emesene.org', '<3 debian', e3.status.BUSY,
                 '', False)
-        self._add_contact('cloud@emesene.org',
-        '·$,32·$59«·$,41·$50«·$,50·$41«·$,59·$32«·$,66·$23«·$32,1« :: nube ::»·$,66·$23»·$,59·$32»·$,50·$41»·$,41·$50»·$,32·$59»·0 ·$0',
-        e3.status.BUSY, '', False)
+        self._add_contact('cloud@emesene.org', 'nube', e3.status.BUSY,
+                '', False)
         self._add_contact('otacon@emesene.org', 'Otacon', e3.status.BUSY,
                 '', True)
         self._add_contact('federico@emesene.org', 'federico..', e3.status.AWAY,
@@ -75,37 +74,46 @@ class Worker(e3.Worker):
                 '[c=29]•°o.Orandom εïз stuff O.o°•[/c=36]·$28',
                 e3.status.BUSY, '', False)
         self._add_contact('four@hotmail.com',
-            '[c=48][b]hy[/b][/c=11] ·#·$3,3\'_·$#fcfcfc,#fcfcfc\'_·$4,4\'_·0·$28',
-            e3.status.BUSY, '', False)
+                '[c=48][b]hy[/b][/c=11] ·#·$3,3\'_·$#fcfcfc,#fcfcfc\'_·$4,4\'_·0·$28',
+                e3.status.BUSY, '', False)
         self._add_contact('five@hotmail.com',
-            '·&·#·$9X.|̲̅·$10X·$9̲̅·$10x·$9̲̅·$10x·$9̲̅·$10x·$9̲̅·$10x·$9̲̅|·$10·#',
-            e3.status.BUSY, '', False)
+                '·&·#·$9X.|̲̅·$10X·$9̲̅·$10x·$9̲̅·$10x·$9̲̅·$10x·$9̲̅·$10x·$9̲̅|·$10·#',
+                e3.status.BUSY, '', False)
         self._add_contact('six@hotmail.com', '[c=46][u][b]xafd! [/b][/u][/c]',
                 e3.status.BUSY, '', False)
         self._add_contact('seven@hotmail.com',
                 '[c=5]((_...sdsdf..._))..)_<(_))(°.°)(...][/c=48][u][/u]',
                 e3.status.BUSY, '', False)
         self._add_contact('eight@hotmail.com',
-                '[i][B][c=12]☆[/c=0][c=0]☆[/c=12][c=12]☆[/c=0] (W) [c=12]Bellamezz[/c=49] (F) [c=0]☆[/c=0][c=12]☆[/c=12][c=0]☆[/c=0][/B][/i]',
+                '[i][B][C=12]☆[/C=0][C=0]☆[/C=12][c=12]☆[/c=0] (W) [C=12]Bellamezz[/c=49] (F) [c=0]☆[/c=0][c=12]☆[/c=12][c=0]☆[/c=0][/B][/i]',
                 e3.status.BUSY, '', False)
         self._add_contact('nine@hotmail.com',
                 '[b](*) ... [c=12]Ricky[/c=33] ...(*)[/b]',
                 e3.status.BUSY, '', False)
         self._add_contact('ten@hotmail.com',
-            '<:o)[c=yellow]Yellow:DYellow[/c][c=red]Red[c=blue]Blue:)Blue[c=green]Green[/c][/c][/c]',
-            e3.status.BUSY, '', False)
+                '<:o)[c=yellow]Yellow:DYellow[/c][c=red]Red[c=blue]Blue:)Blue[c=green]Green[/c][/c][/c]',
+                e3.status.BUSY, '', False)
+        self._add_contact('eleven@hotmail.com',
+                '·$,32·$59«·$,41·$50«·$,50·$41«·$,59·$32«·$,66·$23«·$32,1« :: nube ::»·$,66·$23»·$,59·$32»·$,50·$41»·$,41·$50»·$,32·$59»·0 ·$0',
+                e3.status.BUSY, '', False)
+        self._add_contact('twelve@hotmail.com',
+                '·$4Red·$11Aqua·$6,8PurpleOnYellow·$14GrayOnYellow·0Black·$9Lime',
+                e3.status.BUSY, '', False)
+        self._add_contact('thirteen@hotmail.com',
+                '[c=7][b][I am][/c=yellow][/b][c=89] so [A]wesome that [I] only use invalid tags [/c]',
+                e3.status.BUSY, '', False)
 
         self._add_group('ninjas')
-        self._add_group('pirates')
+        self._add_group('pirätes')
         self._add_group('lulz')
         self._add_group('code quiz ninjas')
         self._add_group('empty')
         self._add_group('strange nicks')
 
-        self._add_contact_to_group('you@emesene.org', 'pirates')
-        self._add_contact_to_group('boyska@emesene.org', 'pirates')
-        self._add_contact_to_group('j0hn@emesene.org', 'pirates')
-        self._add_contact_to_group('c0n0@emesene.org', 'pirates')
+        self._add_contact_to_group('you@emesene.org', 'pirätes')
+        self._add_contact_to_group('boyska@emesene.org', 'pirätes')
+        self._add_contact_to_group('j0hn@emesene.org', 'pirätes')
+        self._add_contact_to_group('c0n0@emesene.org', 'pirätes')
         self._add_contact_to_group('nassty@emesene.org', 'lulz')
         self._add_contact_to_group('warlo@emesene.org', 'lulz')
         self._add_contact_to_group('you@emesene.org', 'lulz')
@@ -125,6 +133,10 @@ class Worker(e3.Worker):
         self._add_contact_to_group('seven@hotmail.com', 'strange nicks')
         self._add_contact_to_group('eight@hotmail.com', 'strange nicks')
         self._add_contact_to_group('nine@hotmail.com', 'strange nicks')
+        self._add_contact_to_group('ten@hotmail.com', 'strange nicks')
+        self._add_contact_to_group('eleven@hotmail.com', 'strange nicks')
+        self._add_contact_to_group('twelve@hotmail.com', 'strange nicks')
+        self._add_contact_to_group('thirteen@hotmail.com', 'strange nicks')
 
     def _add_contact(self, mail, nick, status_, alias, blocked):
         """
