@@ -24,7 +24,6 @@ import sys
 import time
 import Queue
 import base64
-import sha
 import hashlib
 import e3
 import StringIO
@@ -64,7 +63,7 @@ class Worker(e3.Worker):
 
     NOTIFICATION_DELAY = 60
 
-    def __init__(self, app_name, session, proxy, mail_client, use_http=False):
+    def __init__(self, app_name, session, proxy, use_http=False):
         '''class constructor'''
         e3.Worker.__init__(self, app_name, session)
         self.jid = xmpp.protocol.JID(session.account.account)
@@ -83,7 +82,6 @@ class Worker(e3.Worker):
                 self.proxy_data['username'] = self.proxy.user
                 self.proxy_data['password'] = self.proxy.passwd
 
-        self.mail_client = mail_client
         self.conversations = {}
         self.rconversations = {}
         self.roster = None
@@ -106,8 +104,6 @@ class Worker(e3.Worker):
             except Queue.Empty:
                 pass
 
-        self.mail_client.stop()
-
     def _change_status(self, status_):
         '''change the user status'''
         contact = self.session.contacts.me
@@ -226,7 +222,7 @@ class Worker(e3.Worker):
         photo_bin = photo.getTag('BINVAL').getData()
         photo_bin = base64.b64decode(photo_bin)
         ext = PHOTO_TYPES[photo_type]
-        photo_hash = sha.new()
+        photo_hash = hashlib.sha1()
         photo_hash.update(photo_bin)
         photo_hash = photo_hash.hexdigest()
 
@@ -252,6 +248,9 @@ class Worker(e3.Worker):
         log.info("New mailbox message received: %s" % mail_message)
         self.session.mail_received(mail_message)
 
+    def _on_social_external_request(self, conn_url):
+        self.session.social_request(conn_url)
+
     # action handlers
     def _handle_action_quit(self):
         '''handle Action.ACTION_QUIT
@@ -312,10 +311,8 @@ class Worker(e3.Worker):
             self.session.account.password) == None:
             self.session.login_failed('Authentication error')
             return
-
+        
         self.session.login_succeed()
-        self.mail_client.register_handler('mailcount', self._on_mailbox_unread_mail_count_changed)
-        self.mail_client.register_handler('mailnew', self._on_mailbox_new_mail_received)
         self.start_time = time.time()
 
         self.client.RegisterHandler('message', self._on_message)
@@ -350,7 +347,6 @@ class Worker(e3.Worker):
 
         self.session.contact_list_ready()
         self._change_status(status_)
-        self.mail_client.start()
 
     def _handle_action_logout(self):
         '''handle Action.ACTION_LOGOUT
