@@ -84,21 +84,16 @@ try:
 except ImportError:
     DBusNetworkChecker = None
 
-try:
-    from gui.base.UnityLauncher import UnityLauncher
-except ImportError:
-    UnityLauncher = None
-
 try:
     from gui import gtkui
 except ImportError, exc:
-    log.error('Cannot import gtkui: %s' % str(exc))
+    print 'Cannot import gtkui: %s' % str(exc)
 
 try:
     from e3 import jabber
 except ImportError, exc:
     jabber = None
-    log.warning('Errors occurred while importing jabber backend: %s' % str(exc))
+    print 'Errors occurred while importing jabber backend: %s' % str(exc)
 
 try:
     from gui import qt4ui
@@ -109,7 +104,7 @@ try:
     from e3 import papylib
 except ImportError, exc:
     papylib = None
-    log.warning('Errors occurred while importing msn backend: %s' % str(exc))
+    print 'Errors occurred while importing msn backend: %s' % str(exc)
 
 from pluginmanager import get_pluginmanager
 import extension
@@ -149,10 +144,15 @@ class Controller(object):
         self._parse_commandline()
         self._setup()
 
-        signal.signal(signal.SIGINT,
-                lambda * args: glib.idle_add(self.close_session()))
-        signal.signal(signal.SIGTERM,
-                lambda * args: glib.idle_add(self.close_session()))
+        if hasattr(signal, 'SIGINT'):
+            signal.signal(signal.SIGINT,
+                lambda * args: glib.idle_add(self.close_session))
+        if hasattr(signal, 'SIGTERM'):
+            signal.signal(signal.SIGTERM,
+                lambda * args: glib.idle_add(self.close_session))
+        if hasattr(signal, 'SIGHUP'):
+            signal.signal(signal.SIGHUP,
+                lambda * args: glib.idle_add(self.close_session))
 
     def _setup(self):
         '''register core extensions'''
@@ -187,13 +187,7 @@ class Controller(object):
         else:
             self.network_checker = None
 
-        if UnityLauncher is not None:
-            extension.category_register('unity launcher', UnityLauncher)
-            extension.set_default('unity launcher', UnityLauncher)
-            self.unity_launcher = extension.get_and_instantiate(
-                    'unity launcher', self.close_session)
-        else:
-            self.unity_launcher = None
+        self.unity_launcher = extension.get_and_instantiate('unity launcher')
 
         extension.category_register('sound', e3.common.Sounds.SoundPlayer,
                 None, True)
@@ -277,6 +271,7 @@ class Controller(object):
 
         # if you add a signal here, add it on _remove_subscriptions
         signals = self.session.signals
+        signals.close.subscribe(self.on_close)
         signals.login_succeed.subscribe(self.on_login_succeed)
         signals.login_failed.subscribe(self.on_login_failed)
         signals.contact_list_ready.subscribe(self.on_contact_list_ready)
@@ -336,6 +331,7 @@ class Controller(object):
             self.timeout_id = None
 
         if self.session is not None:
+            self.session.stop_mail_client()
             self.session.quit()
 
         self.window.on_disconnect(self.close_session)
@@ -362,6 +358,7 @@ class Controller(object):
         '''remove the subscriptions to signals'''
         if self.session is not None:
             signals = self.session.signals
+            signals.close.unsubscribe(self.on_close)
             signals.login_succeed.unsubscribe(self.on_login_succeed)
             signals.login_failed.unsubscribe(self.on_login_failed)
             signals.contact_list_ready.unsubscribe(self.on_contact_list_ready)
@@ -476,8 +473,7 @@ class Controller(object):
         self.tray_icon.set_main(self.session)
 
         self.window.go_main(self.session, self.on_new_conversation,
-            self.on_close, self.on_user_disconnect,
-            self.tray_icon.quit_on_close)
+                            self.tray_icon.quit_on_close)
 
     def _draw_tray_icon(self):
         '''draws the tray icon'''
@@ -488,8 +484,7 @@ class Controller(object):
                 return
             self.tray_icon.set_visible(False)
 
-        handler = gui.base.TrayIconHandler(self.session, gui.theme,
-            self.on_user_disconnect, self.on_close)
+        handler = gui.base.TrayIconHandler(self.session, gui.theme)
         self.tray_icon = trayiconcls(handler, self.window)
 
     def _sync_emesene1(self):
@@ -577,6 +572,8 @@ class Controller(object):
         self._restore_session()
 
         self._sync_emesene1()
+
+        self.session.start_mail_client()
         self.logged_in = True
 
         if self.network_checker is not None:
@@ -601,15 +598,16 @@ class Controller(object):
             self.window.content.clear_connect()
 
         self._new_session(account)
-
+        
         # set default values if not already set
         self.session.config.get_or_set('b_conv_minimized', True)
         self.session.config.get_or_set('b_conv_maximized', False)
         self.session.config.get_or_set('b_mute_sounds', False)
-        self.session.config.get_or_set('b_play_send', True)
+        self.session.config.get_or_set('b_play_send', False)
         self.session.config.get_or_set('b_play_nudge', True)
         self.session.config.get_or_set('b_play_first_send', True)
         self.session.config.get_or_set('b_play_type', True)
+        self.session.config.get_or_set('b_mute_sounds_when_focussed', True)
         self.session.config.get_or_set('b_play_contact_online', True)
         self.session.config.get_or_set('b_play_contact_offline', True)
         self.session.config.get_or_set('b_notify_contact_online', True)
@@ -700,10 +698,7 @@ class Controller(object):
                 self.conversations.append(conv_manager)
 
                 if self.session.config.b_conv_minimized and other_started:
-                    if UnityLauncher is None:
-                        # FIXME: Dirty hack that makes sure windows don't
-                        # magically disappear on Oneiric
-                        window.iconify()
+                    window.iconify()
                     window.show()
                     window.iconify()
                 else:
@@ -728,9 +723,7 @@ class Controller(object):
             conv_manager.present(conversation)
 
 
-        if not self.session.config.b_mute_sounds and other_started and \
-           self.session.contacts.me.status != e3.status.BUSY and \
-           self.session.config.b_play_first_send and not \
+        if self.session.config.b_play_first_send and not \
            self.session.config.b_play_type:
             self.soundPlayer.play(gui.theme.sound_theme.sound_type)
 
@@ -760,16 +753,11 @@ class Controller(object):
         conv_manager.close_all()
         self.conversations.remove(conv_manager)
 
-    def on_user_disconnect(self):
-        '''
-        method called when the user selects disconnect
-        '''
-        self.close_session(False)
-        self.go_login(cancel_clicked=True, no_autologin=True)
-
-    def on_close(self):
-        '''called on close'''
-        self.close_session()
+    def on_close(self, close=False):
+        '''called when the session is closed by the user'''
+        self.close_session(close)
+        if not close:
+            self.go_login(cancel_clicked=True, no_autologin=True)
 
     def on_disconnected(self, reason, reconnect=0):
         '''called when the server disconnect us'''
