@@ -78,23 +78,35 @@ class AdiumTheme(object):
         self.outgoing_next = read_file(self.outgoing_path,
                 'NextContent.html')
 
+        #setup incoming template fallback
+        if self.incoming is None:
+            self.incoming = self.content
+        if self.incoming_next is None:
+            self.incoming_next = self.incoming
+
+        #setup incoming template fallback
+        if self.outgoing is None:
+            self.outgoing = self.incoming
+        if self.outgoing_next is None:
+            self.outgoing_next = self.outgoing
+
+        #first try load custom Template.html from theme
+        template_path = urljoin(self.resources_path, 'Template.html')
+        if not os.path.exists(template_path):
+            template_path = urljoin("gui", "base", "template.html")
+        self.template = read_file(template_path)
+
+        self.header = read_file(self.resources_path, 'Header.html') or ""
+        self.footer = read_file(self.resources_path, 'Footer.html') or ""
+
     def _format_incoming(self, msg):
         '''return a string containing the template for the incoming message
         with the vars replaced
         '''
-        # fallback madness, some repetition but well..
         if (msg.type == "status" and self.status):
             template = self.status
         elif not msg.first:
-            if self.incoming_next is None:
-                if self.incoming is None:
-                    template = self.content
-                else:
-                    template = self.incoming
-            else:
-                template = self.incoming_next
-        elif self.incoming is None:
-            template = self.content
+            template = self.incoming_next
         else:
             template = self.incoming
 
@@ -104,25 +116,10 @@ class AdiumTheme(object):
         '''return a string containing the template for the outgoing message
         with the vars replaced
         '''
-        # fallback madness, some repetition but well..
         if (msg.type == "status" and self.status):
             template = self.status
         elif not msg.first:
-            if self.outgoing_next is None:
-                if self.outgoing is None:
-                    if self.incoming is None:
-                        template = self.content
-                    else:
-                        template = self.incoming
-                else:
-                    template = self.outgoing
-            else:
-                template = self.outgoing_next
-        elif self.outgoing is None:
-            if self.incoming is None:
-                template = self.content
-            else:
-                template = self.incoming
+            template = self.outgoing_next
         else:
             template = self.outgoing
 
@@ -139,7 +136,6 @@ class AdiumTheme(object):
     def _replace(self, template, msg):
         '''replace the variables on template for the values on msg
         '''
-
         msg.alias = Plus.msnplus_strip(msg.alias)
         msg.display_name = Plus.msnplus_strip(msg.display_name)
 
@@ -213,11 +209,7 @@ class AdiumTheme(object):
     def get_body(self, source, target, target_display, source_img, target_img):
         '''return the template to put as html content
         '''
-        #first try load custom Template.html from theme
-        path = urljoin(self.resources_path, 'Template.html')
-        if not os.path.exists(path):
-            path = urljoin("gui", "base", "template.html")
-        template = read_file(path)
+        template = self.template
         resources_url = MarkupParser.path_to_url(self.resources_path)
         css_path = urljoin(resources_url, "main.css")
 
@@ -237,15 +229,15 @@ class AdiumTheme(object):
         target = Plus.msnplus_strip(target)
         target_display = Plus.msnplus_strip(target_display)
 
-        header = read_file(self.resources_path, 'Header.html') or ""
+        header = self.header
 
         if header:
             header = self._replace_header_or_footer(header, source, target,
                     target_display, source_img, target_img)
 
         template = template.replace("%@", header, 1)
-        footer = read_file(self.resources_path, 'Footer.html') or ""
 
+        footer = self.footer
         if footer:
             footer = self._replace_header_or_footer(footer, source, target,
                     target_display, source_img, target_img)
