@@ -17,7 +17,6 @@
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 import os
-import subprocess
 import sys
 import re
 import time
@@ -46,8 +45,8 @@ EMESENE_LICENSE = '''    emesene is free software; you can redistribute it and/o
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 '''
 
-EMESENE_VERSION = "2.11.9"
-EMESENE_LAST_STABLE = "2.11.9"
+EMESENE_VERSION = "2.11.11"
+EMESENE_LAST_STABLE = "2.11.11"
 EMESENE_WEBSITE = "http://www.emesene.org"
 EMESENE_AUTHORS = "marianoguerra & c10ud"
 EMESENE_CONTRIBUTORS = [ # TODO: Load this from CONTRIBUTORS
@@ -69,10 +68,9 @@ class MenuHandler(object):
     menu items
     '''
 
-    def __init__(self, session, dialog, contact_list, on_disconnect=None,
-            on_quit=None):
+    def __init__(self, session, dialog, contact_list):
         '''constructor'''
-        self.file_handler = FileHandler(session, on_disconnect, on_quit)
+        self.file_handler = FileHandler(session)
         self.actions_handler = ActionsHandler(session, dialog, contact_list)
         self.options_handler = OptionsHandler(session, contact_list)
         self.help_handler = HelpHandler(dialog)
@@ -82,11 +80,9 @@ class FileHandler(object):
     menu items
     '''
 
-    def __init__(self, session, on_disconnect=None, on_quit=None):
+    def __init__(self, session):
         '''constructor'''
         self.session = session
-        self.on_disconnect = on_disconnect
-        self.on_quit = on_quit
 
     def on_status_selected(self, stat):
         '''called when a status is selected on the status menu'''
@@ -94,13 +90,11 @@ class FileHandler(object):
 
     def on_disconnect_selected(self):
         '''called when a status is selected on the status menu'''
-        if self.on_disconnect:
-            self.on_disconnect()
+        self.session.close()
 
     def on_quit_selected(self):
         '''called when a status is selected on the status menu'''
-        if self.on_quit:
-            self.on_quit()
+        self.session.close(True)
 
 class ActionsHandler(object):
     '''this handler contains all the handlers needed to handle the actions
@@ -207,35 +201,32 @@ class HelpHandler(object):
 
     def on_check_update_selected(self):
         ''' checks if a new stable version of emesene is available '''
-        if sys.platform == "darwin":
-            subprocess.call(['open', '/Applications/emesene.app/Contents/Resources/emesene updater.app'])
-        else:
-            f = urllib.urlopen("https://github.com/emesene/emesene/raw/master/emesene/gui/base/Handler.py")
-            s = f.read()
-            f.close()
-            s = re.findall(r'EMESENE_LAST_STABLE = "(([^"\\]+|\\.)*)"', s)
-            try:
-                loc_ver = EMESENE_VERSION.split(".")
-                rem_ver = s[0][0].split(".") # [("version","version")]
-                if len(rem_ver[2]) > 2:
-                    return # no RCs, BETAs or DEVELs
-                if len(loc_ver[2]) > 2:
-                    self.dialog.information(_("You're running a development version of emesene, "
-                                              "you might want to use the latest stable version "
-                                              "(%s) unless you know what you're doing") % (s[0][0]))
+        f = urllib.urlopen("https://github.com/emesene/emesene/raw/master/emesene/gui/base/Handler.py")
+        s = f.read()
+        f.close()
+        s = re.findall(r'EMESENE_LAST_STABLE = "(([^"\\]+|\\.)*)"', s)
+        try:
+            loc_ver = EMESENE_VERSION.split(".")
+            rem_ver = s[0][0].split(".") # [("version","version")]
+            if len(rem_ver[2]) > 2:
+                return # no RCs, BETAs or DEVELs
+            if len(loc_ver[2]) > 2:
+                self.dialog.information(_("You're running a development version of emesene, "
+                                          "you might want to use the latest stable version "
+                                          "(%s) unless you know what you're doing") % (s[0][0]))
+                return
+            if int(loc_ver[0]) == int(rem_ver[0]):
+                if int(loc_ver[1]) < int(rem_ver[1]):
+                    self.notify_update(s[0][0])
                     return
-                if int(loc_ver[0]) == int(rem_ver[0]):
-                    if int(loc_ver[1]) < int(rem_ver[1]):
+                elif int(loc_ver[1]) == int(rem_ver[1]):
+                    if int(loc_ver[2]) < int(rem_ver[2]):
                         self.notify_update(s[0][0])
                         return
-                    elif int(loc_ver[1]) == int(rem_ver[1]):
-                        if int(loc_ver[2]) < int(rem_ver[2]):
-                            self.notify_update(s[0][0])
-                            return
-            except IndexError:
-                pass # Silently fail
+        except IndexError:
+            pass # Silently fail
 
-            self.dialog.information(_("No update available"))
+        self.dialog.information(_("No update available"))
 
 class ContactHandler(object):
     '''this handler contains all the handlers needed to handle the contact
@@ -592,7 +583,7 @@ class TrayIconHandler(FileHandler):
         session -- a e3.Session implementation
         theme -- a gui.Theme object
         """
-        FileHandler.__init__(self, session, on_disconnect, on_quit)
+        FileHandler.__init__(self, session)
         self.theme = theme
         
     def on_hide_show_mainwindow(self, main_window=None):
@@ -668,4 +659,3 @@ class CallHandler(object):
         ''' cancels a call '''
         self.call.state = e3.base.Call.FAILED
         self.session.cancel_call(self.call)
-
