@@ -50,18 +50,18 @@ class Theme(object):
         config_sound_themes_path = os.path.join(config_themes_path, "sounds")
         ensure_dir_path(config_sound_themes_path)
 
-        sound_theme_path = os.path.join("themes", "sounds")
+        sound_theme_path = os.path.join(os.getcwd(), "themes", "sounds")
         self.sound_themes = SoundThemes.SoundThemes()
         self.sound_themes.add_themes_path(sound_theme_path)
         self.sound_themes.add_themes_path(config_sound_themes_path)
 
-        config_emotes_themes_path = os.path.join(config_themes_path, "emotes")
-        ensure_dir_path(config_emotes_themes_path)
+        config_emote_themes_path = os.path.join(config_themes_path, "emotes")
+        ensure_dir_path(config_emote_themes_path)
 
-        emotes_themes_path = os.path.join(os.getcwd(), "themes", "emotes")
-        self.emotes_themes = AdiumEmoteThemes.AdiumEmoteThemes()
-        self.emotes_themes.add_themes_path(emotes_themes_path)
-        self.emotes_themes.add_themes_path(config_emotes_themes_path)
+        emote_themes_path = os.path.join(os.getcwd(), "themes", "emotes")
+        self.emote_themes = AdiumEmoteThemes.AdiumEmoteThemes()
+        self.emote_themes.add_themes_path(emote_themes_path)
+        self.emote_themes.add_themes_path(config_emote_themes_path)
 
         config_images_themes_path = os.path.join(config_themes_path, "images")
         ensure_dir_path(config_images_themes_path)
@@ -77,10 +77,30 @@ class Theme(object):
         '''set the theme name and change all the paths to reflect the change'''
 
         # conv_name is the name of the selected adium conversation theme
-        self.conv_theme = self.conv_themes.get_conv_theme (conv_name, conv_variant)
-        self.sound_theme = self.sound_themes.get_sound_theme (sound_name)
-        self.image_theme = self.image_themes.get_image_theme (image_name)
-        self.emote_theme = self.emotes_themes.get_emote_theme (emote_name)
+        self._conv_theme = self.conv_themes.get_theme(conv_name, conv_variant)
+        self._sound_theme = self.sound_themes.get_theme(sound_name)
+        self.image_theme = self.image_themes.get_theme(image_name)
+        self.emote_theme = self.emote_themes.get_theme(emote_name)
+
+    def _get_conv_theme(self):
+        '''return the conversation theme'''
+        return self._conv_theme
+
+    def _set_conv_theme(self, conv_name):
+        '''set the conversation theme with default variant'''
+        self._conv_theme = self.conv_themes.get_theme (conv_name, '')
+
+    conv_theme = property(fget=_get_conv_theme, fset=_set_conv_theme)
+
+    def _get_sound_theme(self):
+        '''return the sound theme'''
+        return self._sound_theme
+
+    def _set_sound_theme(self, sound_name):
+        '''set the sound theme'''
+        self._sound_theme = self.sound_themes.get_theme (sound_name)
+
+    sound_theme = property(fget=_get_sound_theme, fset=_set_sound_theme)
 
     def get_image_themes(self):
         '''return a list of names for the image themes'''
@@ -88,7 +108,7 @@ class Theme(object):
 
     def get_emote_themes(self):
         '''return a list of names for the emote themes'''
-        return self.emotes_themes.get_name_list()
+        return self.emote_themes.get_name_list()
 
     def get_sound_themes(self):
         '''return a list of names for the sound themes'''
