@@ -28,7 +28,7 @@ import extension
 import logging
 
 import Tooltips
-import Renderers
+from gui.base import Plus
 
 log = logging.getLogger('gtkui.ContactList')
 
@@ -215,7 +215,7 @@ class ContactList(gui.ContactList, gtk.TreeView):
         if not obj:
             return
 
-        if type(obj) == e3.Group:
+        if isinstance(obj, e3.Group):
             if not self.show_empty_groups:
                 if special and obj.type == e3.Group.OFFLINE:
                     return True
@@ -225,9 +225,15 @@ class ContactList(gui.ContactList, gtk.TreeView):
 
                 # get a list of contact objects from a list of accounts
                 contacts = self.contacts.get_contacts(obj.contacts)
-                if self.contacts.get_online_total_count(contacts)[0] == 0:
+                con_on, con_tot = self.contacts.get_online_total_count(contacts)
+                if con_on == 0:
                     return False
 
+                if not self.show_blocked:
+                    if len([contact for contact in contacts \
+                       if contact.blocked]) == con_on:
+                        return False
+
             return True
 
         # i think joining all the text from a user with a new line between
@@ -267,11 +273,11 @@ class ContactList(gui.ContactList, gtk.TreeView):
             return -1
         elif special1 and not special2:
             return 1
-        elif type(obj1) == e3.Group and type(obj2) == e3.Group:
+        elif isinstance(obj1, e3.Group) and isinstance(obj2, e3.Group):
             return self.compare_groups(obj1, obj2, order1, order2)
-        elif type(obj1) == e3.Contact and type(obj2) == e3.Contact:
+        elif isinstance(obj1, e3.Contact) and isinstance(obj2, e3.Contact):
             return self.compare_contacts(obj1, obj2, order1, order2)
-        elif type(obj1) == e3.Group and type(obj2) == e3.Contact:
+        elif isinstance(obj1, e3.Group) and isinstance(obj2, e3.Contact):
             return -1
         else:
             return 1
@@ -317,22 +323,16 @@ class ContactList(gui.ContactList, gtk.TreeView):
                 child_iter = self.model.convert_iter_to_child_iter(iterator)
                 obj = self._model[child_iter][1]
 
-                if type(obj) == e3.Group:
+                if isinstance(obj, e3.Group):
                     self.group_menu_selected.emit(obj)
-                elif type(obj) == e3.Contact:
+                elif isinstance(obj, e3.Contact):
                     self.contact_menu_selected.emit(obj)
             else:
                 log.debug('empty paths?')
 
-    def _markup_escape_group(self, group):
-        '''return group with escaped markup'''
-        return gobject.markup_escape_text(group.name)
-
-    def _markup_escape_contact(self, contact):
-        '''return contact with escaped markup'''
-        escape = gobject.markup_escape_text
-        return (escape(contact.display_name), escape(contact.nick),
-                escape(contact.message))
+    def escaper(self, text):
+        ''' escape the text, this is a toolkit dependant method '''
+        return gobject.markup_escape_text(text)
 
     # overrided methods
     def refilter(self):
@@ -351,7 +351,7 @@ class ContactList(gui.ContactList, gtk.TreeView):
         if row[6]:
             return False
 
-        return type(row[1]) == e3.Group
+        return isinstance(row[1], e3.Group)
 
     def is_contact_selected(self):
         '''return True if a contact is selected'''
@@ -360,7 +360,7 @@ class ContactList(gui.ContactList, gtk.TreeView):
         if selected is None:
             return False
 
-        return type(self._model[selected][1]) == e3.Contact
+        return isinstance(self._model[selected][1], e3.Contact)
 
     def get_group_selected(self):
         '''return a group object if there is a group selected, None otherwise
@@ -423,12 +423,12 @@ class ContactList(gui.ContactList, gtk.TreeView):
         self.session.config.d_weights[group.identifier] = weight
 
         group_data = (None, group,
-            self.format_group(group, self._markup_escape_group(group)),
+            self.format_group(group),
             False, None, False, weight, special)
 
         for row in self._model:
             obj = row[1]
-            if type(obj) == e3.Group:
+            if isinstance(obj, e3.Group):
                 if obj.name == group.name:
                     log.debug('Trying to add an existing group! ' + obj.name)
                     return row.iter
@@ -442,7 +442,7 @@ class ContactList(gui.ContactList, gtk.TreeView):
         for row in self._model:
             obj = row[1]
 
-            if type(obj) == e3.Group and obj.name == group.name:
+            if isinstance(obj, e3.Group) and obj.name == group.name:
                 del self._model[row.iter]
 
     def add_contact(self, contact, group=None):
@@ -458,7 +458,7 @@ class ContactList(gui.ContactList, gtk.TreeView):
         is_online  = not offline
 
         contact_data = (self._get_contact_pixbuf_or_default(contact),
-            contact, self.format_nick(contact, self._markup_escape_contact(contact)), True,
+            contact, self.format_nick(contact), True,
             utils.safe_gtk_pixbuf_load(gui.theme.image_theme.status_icons[contact.status]),
             weight, False, offline)
 
@@ -516,20 +516,20 @@ class ContactList(gui.ContactList, gtk.TreeView):
             for row in self._model:
                 obj = row[1]
                 # check on group
-                if type(obj) == e3.Group:
+                if isinstance(obj, e3.Group):
                     for contact_row in row.iterchildren():
                         con = contact_row[1]
                         if con.account == contact.account:
                             return contact_row.iter
                 # check on the root
-                elif type(obj) == e3.Contact and obj.account == contact.account:
+                elif isinstance(obj, e3.Contact) and obj.account == contact.account:
                     return row.iter
 
             return self._model.append(None, contact_data)
 
         for row in self._model:
             obj = row[1]
-            if type(obj) == e3.Group and obj.name == group.name:
+            if isinstance(obj, e3.Group) and obj.name == group.name:
                 # if the contact is already on the group, then dont add it
                 for contact_row in row.iterchildren():
                     con = contact_row[1]
@@ -543,7 +543,7 @@ class ContactList(gui.ContactList, gtk.TreeView):
                 # since we added him to a group
                 for irow in self._model:
                     iobj = irow[1]
-                    if type(iobj) == e3.Contact and \
+                    if isinstance(iobj, e3.Contact) and \
                             iobj.account == contact.account:
                         del self._model[irow.iter]
 
@@ -564,7 +564,7 @@ class ContactList(gui.ContactList, gtk.TreeView):
             for row in self._model:
                 obj = row[1]
                 # if we get a group we go through the contacts
-                if type(obj) == e3.Group:
+                if isinstance(obj, e3.Group):
                     for contact_row in row.iterchildren():
                         con = contact_row[1]
                         # if we find it, we remove it
@@ -577,7 +577,7 @@ class ContactList(gui.ContactList, gtk.TreeView):
                             self.update_group(obj)
 
                 # if it's a contact without group (at the root)
-                elif type(obj) == e3.Contact and obj.account == contact.account:
+                elif isinstance(obj, e3.Contact) and obj.account == contact.account:
                     # TODO: Is removing only the tree object?
                     del self._model[row.iter]
                     del obj # CHECK!!!!!
@@ -588,7 +588,7 @@ class ContactList(gui.ContactList, gtk.TreeView):
         for row in self._model:
             obj = row[1]
             # if it's the group we are searching
-            if type(obj) == e3.Group and obj.name == group.name:
+            if isinstance(obj, e3.Group) and obj.name == group.name:
                 # go through all the contacts
                 for contact_row in row.iterchildren():
                     con = contact_row[1]
@@ -634,7 +634,7 @@ class ContactList(gui.ContactList, gtk.TreeView):
         online  = not offline
 
         contact_data = (self._get_contact_pixbuf_or_default(contact),
-            contact, self.format_nick(contact, self._markup_escape_contact(contact)), True,
+            contact, self.format_nick(contact), True,
             utils.safe_gtk_pixbuf_load(gui.theme.image_theme.status_icons[contact.status]),
             weight, False, offline)
 
@@ -644,7 +644,7 @@ class ContactList(gui.ContactList, gtk.TreeView):
         for row in self._model:
             obj = row[1]
 
-            if type(obj) == e3.Group:
+            if isinstance(obj, e3.Group):
                 for contact_row in row.iterchildren():
                     con = contact_row[1]
 
@@ -654,7 +654,7 @@ class ContactList(gui.ContactList, gtk.TreeView):
                         self._model[contact_row.iter] = contact_data
                         self.update_group(obj)
 
-            elif type(obj) == e3.Contact and obj.account == contact.account:
+            elif isinstance(obj, e3.Contact) and obj.account == contact.account:
                 found = True
                 self._model[row.iter] = contact_data
 
@@ -690,7 +690,7 @@ class ContactList(gui.ContactList, gtk.TreeView):
             return
 
         group_data = (None, self.no_group,
-            self.format_group(self.no_group, self._markup_escape_group(self.no_group)),
+            self.format_group(self.no_group),
             False, None, 0, True, False)
 
         self._model[self.no_group_iter] = group_data
@@ -699,7 +699,7 @@ class ContactList(gui.ContactList, gtk.TreeView):
     def update_online_group(self):
         '''update the special "Online" group '''
         group_data = (None, self.online_group,
-            self.format_group(self.online_group, self._markup_escape_group(self.online_group)),
+            self.format_group(self.online_group),
             False, None, 0, True, False)
 
         self._model[self.online_group_iter] = group_data
@@ -708,7 +708,7 @@ class ContactList(gui.ContactList, gtk.TreeView):
     def update_offline_group(self):
         '''update the special "Offline" group'''
         group_data = (None, self.offline_group,
-            self.format_group(self.offline_group, self._markup_escape_group(self.offline_group)),
+            self.format_group(self.offline_group),
             False, None, 0, True, False)
 
         self._model[self.offline_group_iter] = group_data
@@ -718,7 +718,7 @@ class ContactList(gui.ContactList, gtk.TreeView):
         ''' restore groups after a search'''
         for row in self._model:
             obj = row[1]
-            if type(obj) == e3.Group:
+            if isinstance(obj, e3.Group):
                 self.update_group(obj)
 
     def update_group(self, group):
@@ -733,12 +733,13 @@ class ContactList(gui.ContactList, gtk.TreeView):
 
         for row in self._model:
             obj = row[1]
-            if type(obj) == e3.Group and obj.identifier == group.identifier:
+            if isinstance(obj, e3.Group) and obj.identifier == group.identifier:
+                path = None
+                childpath = None
                 if group.name in self.group_state:
                     state = self.group_state[group.name]
                     childpath = self._model.get_path(row.iter)
                     path = self.model.convert_child_path_to_path(childpath)
-
                     if path:
                         if state:
                             self.expand_row(path, False)
@@ -747,11 +748,16 @@ class ContactList(gui.ContactList, gtk.TreeView):
 
                 group.contacts = obj.contacts
                 group_data = (None, group,
-                    self.format_group(group, self._markup_escape_group(group)),
+                    self.format_group(group),
                     False, None, weight, (group.type != e3.base.Group.STANDARD), False)
 
                 self._model[row.iter] = group_data
 
+                if path is None and childpath is not None:
+                    path = self.model.convert_child_path_to_path(childpath)
+                    if path and state:
+                        self.expand_row(path, False)
+
     def set_avatar_size(self, size):
         """set the size of the avatars on the contact list
         """
@@ -770,8 +776,8 @@ class ContactList(gui.ContactList, gtk.TreeView):
             return override
 
         if self.order_by_name:
-            return cmp(Renderers.msnplus_to_plain_text(contact1.display_name),
-                       Renderers.msnplus_to_plain_text(contact2.display_name))
+            return cmp(Plus.msnplus_strip(contact1.display_name),
+                       Plus.msnplus_strip(contact2.display_name))
 
         result = cmp(e3.status.ORDERED.index(contact1.status),
             e3.status.ORDERED.index(contact2.status))
@@ -796,7 +802,7 @@ class ContactList(gui.ContactList, gtk.TreeView):
         '''check if the contact isn't there already'''
         for row in self._model:
             obj = row[1]
-            if type(obj) == e3.Group:
+            if isinstance(obj, e3.Group):
                 for contact_row in row.iterchildren():
                     con = contact_row[1]
                     if con.account == contact.account:
@@ -817,18 +823,18 @@ class ContactList(gui.ContactList, gtk.TreeView):
                 display_name = gui.base.Plus.parse_emotes(display_name) # - emotes
 
                 for x in range(len(display_name)):
-                    if type(display_name[x]) is dict:
+                    if isinstance(display_name[x], dict):
                         display_name[x] = '<img src="file://%s" alt="%s">' %\
                                 (display_name[x]["src"], display_name[x]["alt"])
 
                 selection.set(selection.target,
                     8, u'{0} &lt;<a href="mailto:{1}">{1}</a>&gt;'.format(''.join(display_name), account))
             elif selection.target == 'text/plain':
-                selection.set(selection.target, 8, u'%s <%s>' % (Renderers.msnplus_to_plain_text(display_name), account))
+                selection.set(selection.target, 8, u'%s <%s>' % (Plus.msnplus_strip(display_name), account))
 
     def _on_drag_drop(self, widget, drag_context, x, y, time):
         drag_context.finish(True, False, time)
-        if self.session.config.b_order_by_group:
+        if self.session.config.b_order_by_group:    
             group_src = self.get_contact_selected_group()
 
             pos = widget.get_dest_row_at_pos(x,y)[0][0]
