@@ -107,6 +107,20 @@ class Conversation(gtk.VBox, gui.Conversation):
 
         if len(self.members) == 0:
             self.header.information = ('connecting', 'creating conversation')
+        else:
+            #update adium theme header/footer
+            account = self.members[0]
+            contact = self.session.contacts.get(account)
+            if contact:
+                his_picture = contact.picture or utils.path_to_url(os.path.abspath(gui.theme.image_theme.user))
+                nick = contact.nick
+                display_name = contact.display_name
+            else:
+                his_picture = utils.path_to_url(os.path.abspath(gui.theme.image_theme.user))
+                nick = ""
+                display_name = ""
+            my_picture = self.session.contacts.me.picture or utils.path_to_url(os.path.abspath(gui.theme.image_theme.user))
+            self.output.clear(account, nick, display_name, my_picture, his_picture)
 
         self._load_style()
         
@@ -353,8 +367,10 @@ class Conversation(gtk.VBox, gui.Conversation):
     def on_toggle_avatar(self):
         '''hide or show the avatar bar'''
         if self.avatar_box_is_hidden:
+            self.toolbar.toggle_avatar.set_stock_id(gtk.STOCK_GO_FORWARD)
             self.info.show()
         else:
+            self.toolbar.toggle_avatar.set_stock_id(gtk.STOCK_GO_BACK)
             self.info.hide()
         self.avatar_box_is_hidden = not self.avatar_box_is_hidden
 
@@ -369,7 +385,7 @@ class Conversation(gtk.VBox, gui.Conversation):
 
     def on_filetransfer_invitation(self, transfer, cid):
         ''' called when a new file transfer is issued '''
-        if cid == self.cid:
+        if transfer.contact.account == self.members[0]:
             self.transfers_bar.add(transfer)
 
     def on_filetransfer_accepted(self, transfer):
