@@ -22,7 +22,7 @@ import gtk
 import e3
 import gui
 import extension
-import Renderers
+from gui.base import Plus
 
 class ConversationManager(gtk.Notebook, gui.ConversationManager):
     '''the main conversation, it only contains other widgets'''
@@ -44,7 +44,7 @@ class ConversationManager(gtk.Notebook, gui.ConversationManager):
         #self.set_scrollable(session.config.get_or_set('b_conv_tab_scroll',
         #    True))
 
-        if session.config.get_or_set('b_conv_tab_popup', True):
+        if session.config.get_or_set('b_conv_tab_popup', False):
             self.popup_enable()
 
         # mozilla tabs are fixed-width, otherwise do the same as emesene-1
@@ -65,7 +65,7 @@ class ConversationManager(gtk.Notebook, gui.ConversationManager):
                 self.cycle_tabs()
             return True
 
-    def _on_tab_position_changed(self,value):
+    def _on_tab_position_changed(self, value):
         '''callback called when i_tab_position changes'''
         self.set_tab_pos(pos=self.get_tab_position())
 
@@ -84,9 +84,10 @@ class ConversationManager(gtk.Notebook, gui.ConversationManager):
         accel_group.connect_group(gtk.keysyms.W, \
                                   gtk.gdk.CONTROL_MASK, gtk.ACCEL_LOCKED, \
                                   self.on_key_close_tab)
-        accel_group.connect_group(gtk.keysyms.Escape, \
-                                  0, gtk.ACCEL_LOCKED, \
-                                  self.on_key_close_tab)
+        if self.session.config.get_or_set('b_escape_hotkey', True):
+            accel_group.connect_group(gtk.keysyms.Escape, \
+                                      0, gtk.ACCEL_LOCKED, \
+                                      self.on_key_close_tab)
 
         for i in range(1, 10):
             accel_group.connect_group(gtk.keysyms._0 + i,
@@ -165,7 +166,7 @@ class ConversationManager(gtk.Notebook, gui.ConversationManager):
             self.session.add_event(e3.Event.EVENT_MESSAGE_READ, page)
             self.set_message_waiting(page, False)
         if page.show_avatar_in_taskbar:
-            self.update_window(page.text, page.his_avatar.filename, self.get_current_page())
+            self.update_window(page.text, page.info.his_avatar.filename, self.get_current_page())
         else:
             self.update_window(page.text, page.icon, self.get_current_page())
         page.input_grab_focus()
@@ -200,6 +201,12 @@ class ConversationManager(gtk.Notebook, gui.ConversationManager):
         #       Signals are being unsubscribed (see gtkui.Conversation) but...
         conversation.tab_index = -2
 
+    def after_close(self):
+         #If has one tab hide close button
+        if len(self.conversations) == 1:
+           for k, v in self.conversations.items():
+                v.tab_label.close.hide()
+
     def add_new_conversation(self, session, cid, members):
         """
         create and append a new conversation
@@ -211,12 +218,20 @@ class ConversationManager(gtk.Notebook, gui.ConversationManager):
             conversation, self.mozilla_tabs)
         label.set_image(gui.theme.image_theme.connect)
         conversation.tab_label = label
-        conversation.tab_index=self.append_page_menu(conversation, label)
+        conversation.tab_index = self.append_page_menu(conversation, label)
         self.set_tab_label_packing(conversation, not self.mozilla_tabs, True, gtk.PACK_START)
         self.set_tab_reorderable(conversation, True)
 
         return conversation
 
+    def after_new_conversation(self, conversation):
+         #If has more than one tab show close buttons
+        if len(self.conversations) > 2:
+          conversation.tab_label.close.show()
+        elif len(self.conversations) == 2:
+            for k, v in self.conversations.items():
+                v.tab_label.close.show()
+
     def update_window(self, text, icon, index):
         ''' updates the window's border and item on taskbar
             with given text and icon '''
@@ -224,7 +239,7 @@ class ConversationManager(gtk.Notebook, gui.ConversationManager):
             win = self.get_parent() # gtk.Window, not a nice hack.
             if win is None:
                 return
-            win.set_title(Renderers.msnplus_to_plain_text(text))
+            win.set_title(Plus.msnplus_strip(text))
             win.set_icon(icon)
 
     def present(self, conversation):
@@ -243,8 +258,8 @@ class ConversationManager(gtk.Notebook, gui.ConversationManager):
         return self.get_parent().get_dimensions()
 
     def get_tab_position(self):
-        positions = [gtk.POS_TOP,gtk.POS_BOTTOM,gtk.POS_LEFT,gtk.POS_RIGHT]
-        return positions[self.session.config.get_or_set('i_tab_position',0)]
+        positions = [gtk.POS_TOP, gtk.POS_BOTTOM, gtk.POS_LEFT, gtk.POS_RIGHT]
+        return positions[self.session.config.get_or_set('i_tab_position', 0)]
 
     def hide_all(self):
         '''
