@@ -69,7 +69,12 @@ class Dialog(object):
     def window_add_label(cls, window, text):
         '''add a label with the text (as pango) on the window'''
 
+        def on_activate_link(label, uri):
+            gui.base.Desktop.open(uri)
+            return True
+
         label = gtk.Label()
+        label.connect('activate-link', on_activate_link)
         #label.set_selectable(True)
         label.set_use_markup(True)
         label.set_markup('<span>' + \
@@ -969,6 +974,13 @@ class Dialog(object):
         dialog.show_all()
         return dialog
 
+    @classmethod
+    def facebook_token_window(cls, title, callback):
+        '''returns a progress window used for emesene 1 synch'''
+        dialog = FacebookTokenWindow(title, callback)
+        dialog.show_all()
+        return dialog
+
     @classmethod
     def broken_profile(cls, close_cb):
         '''a dialog that asks you to fix your profile'''
@@ -1790,3 +1802,42 @@ class ProgressWindow(gtk.Window):
         '''called when the action changes'''
         self.desclabel.set_text(action)
 
+class FacebookTokenWindow(gtk.Window):
+    '''A class for a progressbar dialog'''
+
+    def __init__(self, title, callback):
+        '''Constructor. Packs widgets'''
+        gtk.Window.__init__(self)
+        self._callback = callback
+        self.set_title(title)
+        self.set_role("dialog")
+        self.set_modal(True)
+        self.buttoncancel = gtk.Button()
+        self.buttoncancel.set_label(_("Cancel"))
+        self.buttoncancel.connect('clicked', self.on_click_cancel)
+        self.buttonok = gtk.Button()
+        self.buttonok.set_label(_("Ok"))
+        self.buttonok.connect('clicked', self.on_click_ok)
+        self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_DIALOG)
+        self.set_default_size(300, 50)
+        self.set_position(gtk.WIN_POS_CENTER)
+        self.set_border_width(8)
+        hbox = gtk.HBox()
+        vbox = gtk.VBox()
+        self.text_token = gtk.TextView()
+        vbox.pack_start(self.text_token)
+        hbox.pack_start(self.buttonok)
+        hbox.pack_start(self.buttoncancel)
+        vbox.pack_start(hbox)
+        self.add(vbox)
+
+    def on_click_ok(self, widget):
+        buffer = self.text_token.get_buffer()
+        (start, end) = buffer.get_bounds()
+        token = buffer.get_text(start, end)
+        self._callback(token)
+        self.destroy()
+
+    def on_click_cancel(self, widget):
+        self.destroy()
+        
