@@ -21,6 +21,8 @@ import gtk
 import e3.common
 import gui
 import utils
+import subprocess
+import sys
 import extension
 import stock
 
@@ -539,6 +541,20 @@ class MainWindow(BaseTable):
         self.append_entry_default(_('Group format'), 'group',
                 'session.config.group_template', ContactList.GROUP_TPL)
 
+        if sys.platform == 'darwin':
+
+            def do_hideshow(widget):
+                if widget.get_active():
+                    subprocess.call('defaults write /Applications/emesene.app/Contents/Info LSUIElement -bool false', shell=True)
+                else:
+                    subprocess.call('defaults write /Applications/emesene.app/Contents/Info LSUIElement -bool true', shell=True)
+
+            self.append_markup('<b>'+_('OS X Integration:')+'</b>')
+            self.session.config.get_or_set('b_show_dock_icon', True)    
+            button = self.append_check(_('Show dock icon (requires restart of emesene)'),
+                         'session.config.b_show_dock_icon')
+            button.connect("toggled", do_hideshow)
+
         self.show_all()
 
 class ConversationWindow(BaseTable):
@@ -737,6 +753,8 @@ class Sound(BaseTable):
             'session.config.b_play_type'))
         self.array.append(self.append_check(_('Play sound on nudge'),
             'session.config.b_play_nudge'))
+        self.array.append(self.append_check(_('Mute sounds when the conversation has focus'),
+            'session.config.b_mute_sounds_when_focussed'))
         self.append_markup('<b>'+_('Users events:')+'</b>')
         self.array.append(self.append_check(_('Play sound on contact online'),
             'session.config.b_play_contact_online'))
@@ -779,6 +797,10 @@ class Notification(BaseTable):
         self.append_markup('<b>'+_('Messages events:')+'</b>')
         self.append_check(_('Notify on received message'),
             'session.config.b_notify_receive_message')
+        self.append_check(_('Notify when a contact is typing'),
+            'session.config.b_notify_typing')
+        self.append_check(_('Notify also when the conversation has focus'),
+            'session.config.b_notify_when_focussed')
         self.append_check(_('Only when available'),
             'session.config.b_notify_only_when_available')
         self.show_all()
@@ -1322,4 +1344,4 @@ class PrivacySettings(gtk.VBox):
             if action == stock.YES:
                 self.session.remove_contact(model.get_value(iter, 0))
         except TypeError:
-            pass
+            pass
\ No newline at end of file
